@@ -72,7 +72,8 @@ class MockPopen(object):
               stdin=None, stdout=None, stderr=None,
               preexec_fn=None, close_fds=False, shell=False, cwd=None,
               env=None, universal_newlines=False,
-              startupinfo=None, creationflags=0):
+              startupinfo=None, creationflags=0, restore_signals=True,
+              start_new_session=False, pass_fds=(), encoding=None, errors=None):
 
         if isinstance(args, basestring):
             cmd = args
